# compile dependency issues, scipy-1.73 and numpy-1.22.x don't work well together
# see https://github.com/scipy/scipy/issues/15414
%bcond_with check

%global srcname scikit-learn

Summary: Machine learning in Python
Name: python-scikit-learn
Version: 1.1.2
Release: 2%{?dist}
License: BSD and MIT
URL: http://scikit-learn.org/
Source0: %{pypi_source}

BuildRequires: gcc gcc-c++
BuildRequires: python3-devel %{py3_dist setuptools}

%description
scikit-learn is a Python module for machine learning built upon numpy, scipy, and matplotlib. 
As a machine learning module, it provides universal tools for data mining and analysis in any 
scientific and engineering field.

%package -n python3-%{srcname}
Summary: %{summary}
BuildRequires: %{py3_dist Cython numpy scipy}
%if %{with check}
BuildRequires: python3-pytest
BuildRequires: %{py3_dist joblib}  python3-threadpoolctl >= 2.0.0
%endif
Provides:       python3-sklearn = %{version}-%{release}

%description -n python3-%{srcname}
scikit-learn is a Python module for machine learning built upon numpy, scipy, and matplotlib. 
As a machine learning module, it provides universal tools for data mining and analysis in any 
scientific and engineering field.

%prep
%autosetup -n %{srcname}-%{version}

%build
%py3_build

%install
%py3_install

%if %{with check}
%check
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
pushd %{buildroot}%{python3_sitearch}
  pytest \
  --deselect "metrics/tests/test_common.py::test_not_symmetric_metric[precision_recall_curve]" \
  --deselect "metrics/tests/test_common.py::test_binary_sample_weight_invariance[precision_recall_curve]" \
  --deselect "datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True]" \
  --deselect "datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False]" \
  --deselect "cross_decomposition/tests/test_pls.py::test_loadings_converges" \
  --deselect "covariance/tests/test_graphical_lasso.py::test_graphical_lasso" \
  --deselect "gaussian_process/tests/test_gpr.py::test_lml_precomputed[kernel3]" \
  --deselect "gaussian_process/tests/test_gpr.py::test_lml_precomputed[kernel4]" \
%ifarch ppc64le
  --deselect "neural_network/tests/test_mlp.py::test_mlp_regressor_dtypes_casting" \
%endif
  sklearn 
popd

%endif

%files -n python3-%{srcname}
%license COPYING sklearn/svm/src/liblinear/COPYRIGHT
%doc examples/
%{python3_sitearch}/sklearn
%{python3_sitearch}/scikit_learn-*.egg-info

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Sun Apr 23 2023 Wang Guodong <gordonwwang@tencent.com> - 1.1.2-1
- initial build
